# docassemble.ALAnyState

A ALWeaver capability package and docassemble.AssemblyLine runtime package that provides a simple
look and feel that is lightly customized to each state. It displays the state's seal and uses the
state's name in the navigation bar.

The goal is to also show a rudimentary listing of the court/venue tailored to each state.

## Author

Quinten Steenhuis, qsteenhuis@suffolk.edu

